summaryrefslogtreecommitdiffstats
path: root/filters/kspread/excel
diff options
context:
space:
mode:
authorTimothy Pearson <[email protected]>2011-12-21 14:05:41 -0600
committerTimothy Pearson <[email protected]>2011-12-21 14:05:41 -0600
commit2d6954f69caf63ed5057bd8e1405a65d7d970292 (patch)
tree88e6436b2e81d4e68313f02a9021054252e14cc4 /filters/kspread/excel
parentf0de9e167e289ab7dc33e57f077c1f04ec7c68c8 (diff)
downloadkoffice-2d6954f69caf63ed5057bd8e1405a65d7d970292.tar.gz
koffice-2d6954f69caf63ed5057bd8e1405a65d7d970292.zip
Rename obsolete tq methods to standard names
Diffstat (limited to 'filters/kspread/excel')
-rw-r--r--filters/kspread/excel/sidewinder/excel.cpp28
-rw-r--r--filters/kspread/excel/sidewinder/excel.h4
-rw-r--r--filters/kspread/excel/sidewinder/pole.cpp2
-rw-r--r--filters/kspread/excel/sidewinder/ustring.cpp4
-rw-r--r--filters/kspread/excel/sidewinder/ustring.h4
5 files changed, 21 insertions, 21 deletions
diff --git a/filters/kspread/excel/sidewinder/excel.cpp b/filters/kspread/excel/sidewinder/excel.cpp
index 6985a434..2a3a6247 100644
--- a/filters/kspread/excel/sidewinder/excel.cpp
+++ b/filters/kspread/excel/sidewinder/excel.cpp
@@ -185,7 +185,7 @@ static Value errorAsValue( int errorCode )
class EString::Private
{
public:
- bool tqunicode;
+ bool unicode;
bool richText;
UString str;
unsigned size;
@@ -194,7 +194,7 @@ public:
EString::EString()
{
d = new EString::Private();
- d->tqunicode = false;
+ d->unicode = false;
d->richText = false;
d->str = UString::null;
d->size = 0;
@@ -208,7 +208,7 @@ EString::EString( const EString& es )
EString& EString::operator=( const EString& es )
{
- d->tqunicode = es.d->tqunicode;
+ d->unicode = es.d->unicode;
d->richText = es.d->richText;
d->size = es.d->size;
d->str = es.d->str;
@@ -220,14 +220,14 @@ EString::~EString()
delete d;
}
-bool EString::tqunicode() const
+bool EString::unicode() const
{
- return d->tqunicode;
+ return d->unicode;
}
void EString::setUnicode( bool u )
{
- d->tqunicode = u;
+ d->unicode = u;
}
bool EString::richText() const
@@ -271,7 +271,7 @@ EString EString::fromUnicodeString( const void* p, bool longString, unsigned /*
unsigned char flag = data[ offset ];
offset++; // for flag (1 byte)
- bool tqunicode = flag & 0x01;
+ bool unicode = flag & 0x01;
bool richText = flag & 0x08;
unsigned formatRuns = 0;
@@ -283,10 +283,10 @@ EString EString::fromUnicodeString( const void* p, bool longString, unsigned /*
// find out total bytes used in this string
unsigned size = offset + len; // string data
- if( tqunicode ) size += len; // because tqunicode takes 2-bytes char
+ if( unicode ) size += len; // because unicode takes 2-bytes char
if( richText ) size += (formatRuns*4);
- if( !tqunicode )
+ if( !unicode )
{
char* buffer = new char[ len+1 ];
memcpy( buffer, data + offset, len );
@@ -303,7 +303,7 @@ EString EString::fromUnicodeString( const void* p, bool longString, unsigned /*
}
EString result;
- result.setUnicode( tqunicode );
+ result.setUnicode( unicode );
result.setRichText( richText );
result.setSize( size );
result.setStr( str );
@@ -351,14 +351,14 @@ EString EString::fromSheetName( const void* p, unsigned datasize )
unsigned len = data[0];
unsigned flag = data[1];
- bool tqunicode = flag & 1;
+ bool unicode = flag & 1;
if( len > datasize-2 ) len = datasize-2;
if( len == 0 ) return EString();
unsigned offset = 2;
- if( !tqunicode )
+ if( !unicode )
{
char* buffer = new char[ len+1 ];
memcpy( buffer, data + offset, len );
@@ -376,7 +376,7 @@ EString EString::fromSheetName( const void* p, unsigned datasize )
}
EString result;
- result.setUnicode( tqunicode );
+ result.setUnicode( unicode );
result.setRichText( richText );
result.setSize( datasize );
result.setStr( str );
@@ -2012,7 +2012,7 @@ void BoundSheetRecord::setData( unsigned size, const unsigned char* data )
d->visibility = data[4];
d->type = data[5];
- /* FIXME: it turned out that sheet name is not normal tqunicode string
+ /* FIXME: it turned out that sheet name is not normal unicode string
where the first two bytes specifies string length, but instead
only the first specifies it.
the next byte could be correctly interpreted as flag.
diff --git a/filters/kspread/excel/sidewinder/pole.cpp b/filters/kspread/excel/sidewinder/pole.cpp
index 6f12ae13..e4090cd9 100644
--- a/filters/kspread/excel/sidewinder/pole.cpp
+++ b/filters/kspread/excel/sidewinder/pole.cpp
@@ -95,7 +95,7 @@ class DirEntry
{
public:
bool valid; // false if invalid (should be skipped)
- std::string name; // the name, not in tqunicode anymore
+ std::string name; // the name, not in unicode anymore
bool dir; // true if directory
unsigned long size; // size (not valid if directory)
unsigned long start; // starting block
diff --git a/filters/kspread/excel/sidewinder/ustring.cpp b/filters/kspread/excel/sidewinder/ustring.cpp
index b26ee196..304fed18 100644
--- a/filters/kspread/excel/sidewinder/ustring.cpp
+++ b/filters/kspread/excel/sidewinder/ustring.cpp
@@ -39,7 +39,7 @@ UString UString::null;
static char *statBuffer = 0L;
UChar::UChar(const UCharReference &c)
- : uc( c.tqunicode() )
+ : uc( c.unicode() )
{
}
@@ -579,7 +579,7 @@ bool Swinder::operator<(const UString& s1, const UString& s2)
l++;
}
if (l < lmin)
- return (c1->tqunicode() < c2->tqunicode());
+ return (c1->unicode() < c2->unicode());
return (l1 < l2);
}
diff --git a/filters/kspread/excel/sidewinder/ustring.h b/filters/kspread/excel/sidewinder/ustring.h
index 1c4f2bc5..3f41867b 100644
--- a/filters/kspread/excel/sidewinder/ustring.h
+++ b/filters/kspread/excel/sidewinder/ustring.h
@@ -68,7 +68,7 @@ namespace Swinder {
/**
* @return the 16 bit Unicode value of the character
*/
- unsigned short tqunicode() const { return uc; }
+ unsigned short unicode() const { return uc; }
public:
/**
* A static instance of UChar(0).
@@ -120,7 +120,7 @@ namespace Swinder {
/**
* @return Unicode value.
*/
- unsigned short tqunicode() const { return ref().uc; }
+ unsigned short unicode() const { return ref().uc; }
/**
* @return Lower byte.
*/
diff --git a/filters/kspread/excel/sidewinder/excel.h b/filters/kspread/excel/sidewinder/excel.h
index c05d223b..5221b518 100644
--- a/filters/kspread/excel/sidewinder/excel.h
+++ b/filters/kspread/excel/sidewinder/excel.h
@@ -36,7 +36,7 @@ enum { UnknownExcel = 0, Excel95, Excel97, Excel2000 };
class Record;
// rich-text, tqunicode, far-east support Excel string
class EString
{
@@ -50,7 +50,7 @@ public:
~EString();
- bool tqunicode() const;
+ bool unicode() const;
void setUnicode( bool u );
@@ -36,7 +36,7 @@ enum { UnknownExcel = 0, Excel95, Excel97, Excel2000 };
class Record;
-// rich-text, tqunicode, far-east support Excel string
+// rich-text, unicode, far-east support Excel string
class EString
{